ApbReadPacket class

A read packet on an ApbInterface.

Inheritance

Constructors

ApbReadPacket({required LogicValue addr, int selectIndex = 0})
Creates a read packet.

Properties

addr → LogicValue
The address for this packet.
finalinherited
completed Future<void>
A Future that completes once the the read has been completed.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
logger → Logger
A Logger for messages related to the test or testbench.
latefinalinherited
returnedData → LogicValue?
Data returned by the read.
no setter
returnedSlvErr → LogicValue?
Error indication returned by the read.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectIndex int
The index of the select this packet should be driven on.
finalinherited

Methods

complete({LogicValue? slvErr, LogicValue? data}) → void
Called by a completer when a transfer is completed.
override
fullName() String
A descriptive name representing this instance of the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
trackerString(TrackerField field) String?
Returns a formatted String value associated with field in this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited