tryInput method
Provides the input named name if it exists, otherwise null.
Only logic within this Module should consume this signal.
Implementation
Logic? tryInput(String name) => _inputs[name];
Provides the input named name if it exists, otherwise null.
Only logic within this Module should consume this signal.
Logic? tryInput(String name) => _inputs[name];