ReadyValidTransmitterDriver class
An Agent for transmitting over a ready/valid protocol.
Constructors
-
ReadyValidTransmitterDriver({required Logic clk, required Logic reset, required Logic ready, required Logic valid, required Logic data, required Sequencer<
ReadyValidPacket> sequencer, required Component? parent, double blockRate = 0, String name = 'readyValidTransmitterDriver', int? dropDelayCycles = 30}) -
Creates an
Agentfor transmitting over a ready/valid protocol.
Properties
- blockRate → double
-
Probability (from 0 to 1) of blocking a valid from being driven.
final
- clk → Logic
-
The clock for this driver.
finalinherited
-
components
→ UnmodifiableListView<
Component> -
A List of all children
Components.no setterinherited - data → Logic
-
Data being transmitted.
final
-
dropDelay
→ Future<
void> Function()? -
A function called each time an objection would drop due to an empty
pendingSeqItems, but the objection will only be dropped if there is no further activity before it completes.finalinherited - dropDelayCycles → int?
-
Number of cycles to hold an objection even when no items are pending.
finalinherited
- enableEndOfTestEmptyCheck → bool
-
If
true, willcheckat the end of the test that there are no pending items remaining to be driven.finalinherited - hashCode → int
-
The hash code for this object.
no setterinherited
- logger → Logger
-
A
Loggerfor messages related to the test or testbench.latefinalinherited - name → String
-
A name for this instance of the
Component.finalinherited - parent → Component?
-
The
Componentwhich constructed and contains thisComponent.finalinherited -
pendingSeqItems
↔ Queue<
ReadyValidPacket> -
A Queue of items that have been received from the sequencer and are
waiting to be driven. After an item has been driven, it should be
removed.
latefinalinherited
- ready → Logic
-
Ready signal.
final
- reset → Logic
-
Active-high reset.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sequencer
→ Sequencer<
ReadyValidPacket> -
The sequencer from which this
Driveracquires new items to drive.finalinherited -
timeout
→ Future<
void> Function()? -
A function called each time there is something added or removed from the
pendingSeqItems, and if it completes before an objection is dropped or some further activity occurs, an error is flagged.finalinherited - timeoutCycles → int?
-
Number of cycles before triggering a timeout error.
finalinherited
- valid → Logic
-
Valid signal.
final
- waitEdge → Edge
-
The
Edgeto wait on when counting cycles fortimeoutCyclesanddropDelayCycles.finalinherited
Methods
-
build(
) → void -
Performs additional build-related activities required before
run.inherited -
check(
) → void -
Performs additional checks at the end of the simulation.
inherited
-
fullName(
) → String -
A descriptive name including the full hierarchical path of
this
Component.inherited -
hierarchy(
) → List< Component> -
Returns a List of
Components representing the full hierarchy of thisComponent, with the top-most parent at index 0 and this as the last element of the List.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
Phase phase) → Future< void> -
Executes this
Component's activities related to running the test. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited